package App::ParseNetstat;

our $DATE = '2016-10-17'; # DATE
our $VERSION = '0.14'; # VERSION

1;
# ABSTRACT: Parse netstat output (CLI)

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ParseNetstat - Parse netstat output (CLI)

=head1 VERSION

This document describes version 0.14 of App::ParseNetstat (from Perl distribution App-ParseNetstat), released on 2016-10-17.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ParseNetstat>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-ParseNetstat>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ParseNetstat>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Parse::Netstat>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
